@@ -212,7 +212,6 @@ extern fraction_t best_o2(depth_t depth, const struct dive *dive);
 extern fraction_t best_he(depth_t depth, const struct dive *dive, bool o2narcotic, fraction_t fo2);
 
 extern int get_surface_pressure_in_mbar(const struct dive *dive, bool non_null);
-extern int calculate_depth_to_mbar(int depth, pressure_t surface_pressure, int salinity);
 extern int depth_to_mbar(int depth, const struct dive *dive);
 extern double depth_to_bar(int depth, const struct dive *dive);
 extern double depth_to_atm(int depth, const struct dive *dive);
@@ -249,7 +248,6 @@ extern struct divecomputer *get_dive_dc(struct dive *dive, int nr);
 extern timestamp_t dive_endtime(const struct dive *dive);
 
 extern struct dive *make_first_dc(const struct dive *d, int dc_number);
-extern int count_divecomputers(const struct dive *d);
 extern struct dive *clone_delete_divecomputer(const struct dive *d, int dc_number);
 void split_divecomputer(const struct dive *src, int num, struct dive **out1, struct dive **out2);
 
@@ -362,7 +360,6 @@ extern void invalidate_dive_cache(struct dive *dc);
 
 extern void clear_events(void);
 
-extern void set_dc_nickname(struct dive *dive);
 extern void set_autogroup(bool value);
 extern int total_weight(const struct dive *);
 
