@@ -12,6 +12,10 @@
 #if BT_SUPPORT
 #include "core/btdiscovery.h"
 #endif
+#if defined(Q_OS_ANDROID)
+#include "core/serial_usb_android.h"
+#endif
+
 /* Helper object for access of Device Data in QML */
 class DCDeviceData {
 public:
@@ -31,7 +35,7 @@ public:
 	int diveId() const;
 
 	/* this needs to be a pointer to make the C-API happy */
-	device_data_t* internalData();
+	device_data_t *internalData();
 
 	QStringList getProductListFromVendor(const QString& vendor);
 	int getMatchingAddress(const QString &vendor, const QString &product);
@@ -49,7 +53,13 @@ public:
 	void setForceDownload(bool force);
 	void setSaveDump(bool dumpMode);
 	void setSaveLog(bool saveLog);
+#if defined(Q_OS_ANDROID)
+	void setUsbDevice(const android_usb_serial_device_descriptor &usbDescriptor);
+#endif
 private:
+#if defined(Q_OS_ANDROID)
+	struct android_usb_serial_device_descriptor androidUsbDescriptor;
+#endif
 	device_data_t data;
 
 	// Bluetooth name is managed outside of libdivecomputer
@@ -58,21 +68,17 @@ private:
 
 class DownloadThread : public QThread {
 	Q_OBJECT
-	Q_PROPERTY(dive_table_t *table READ table CONSTANT)
-	Q_PROPERTY(dive_site_table_t *sites READ sites CONSTANT)
 
 public:
 	DownloadThread();
 	void run() override;
 
 	DCDeviceData *data();
-	struct dive_table *table();
-	struct dive_site_table *sites();
 	QString error;
-
-private:
 	struct dive_table downloadTable;
 	struct dive_site_table diveSiteTable;
+
+private:
 	DCDeviceData *m_data;
 };
 
