@@ -136,6 +136,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	char shearwater_cloud_test[] = "select count(*) from sqlite_master where type='table' and name='SyncV3MetadataDiveLog' and sql like '%CreatedDevice%'";
 	char cobalt_test[] = "select count(*) from sqlite_master where type='table' and name='TrackPoints' and sql like '%DepthPressure%'";
 	char divinglog_test[] = "select count(*) from sqlite_master where type='table' and name='DBInfo' and sql like '%PrgName%'";
+	char seacsync_test[] = "select count(*) from sqlite_master where type='table' and name='dive_data' and sql like '%ndl_tts_s%'";
 	int retval;
 
 	retval = sqlite3_open(filename, &handle);
@@ -193,6 +194,15 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 		return retval;
 	}
 
+	/* Testing if DB schema resembles Seac database format */
+	retval = sqlite3_exec(handle, seacsync_test, &db_test_func, 0, NULL);
+	if (!retval) {
+		retval = parse_seac_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		sqlite3_close(handle);
+		return retval;
+	}
+
+
 	sqlite3_close(handle);
 
 	return retval;
@@ -338,8 +348,20 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 
 	/* DataTrak/Wlog */
 	if (fmt && !strcasecmp(fmt + 1, "LOG")) {
-		ret = datatrak_import(&mem, table, trips, sites);
+		struct memblock wl_mem;
+		const char *t = strrchr(filename, '.');
+		char *wl_name = memcpy(calloc(t - filename + 1, 1), filename, t - filename);
+		wl_name = realloc(wl_name, strlen(wl_name) + 5);
+		wl_name = strcat(wl_name, ".add");
+		if((ret = readfile(wl_name, &wl_mem)) < 0) {
+			fprintf(stderr, "No file %s found. No WLog extensions.\n", wl_name);
+			ret = datatrak_import(&mem, NULL, table, trips, sites);
+		} else {
+			ret = datatrak_import(&mem, &wl_mem, table, trips, sites);
+			free(wl_mem.buffer);
+		}
 		free(mem.buffer);
+		free(wl_name);
 		return ret;
 	}
 
