@@ -5,7 +5,6 @@
 #include "core/settings/qPrefUpdateManager.h"
 #include "core/subsurface-qt/divelistnotifier.h"
 #include "subsurface-string.h"
-#include "subsurface-string.h"
 #include "gettextfromc.h"
 #include "statistics.h"
 #include "membuffer.h"
@@ -624,19 +623,37 @@ QString get_pressure_string(pressure_t pressure, bool showunit)
 
 QString get_salinity_string(int salinity)
 {
-        return QStringLiteral("%L1%2").arg(salinity / 10.0).arg(gettextFromC::tr("g/ℓ"));
+	return QStringLiteral("%L1%2").arg(salinity / 10.0).arg(gettextFromC::tr("g/ℓ"));
 }
 
+// the water types need to match the watertypes enum
+static const char *waterTypes[] = {
+	QT_TRANSLATE_NOOP("gettextFromC", "Fresh"),
+	QT_TRANSLATE_NOOP("gettextFromC", "Brackish"),
+	QT_TRANSLATE_NOOP("gettextFromC", "EN13319"),
+	QT_TRANSLATE_NOOP("gettextFromC", "Salt"),
+	QT_TRANSLATE_NOOP("gettextFromC", "Use DC")
+};
+
 QString get_water_type_string(int salinity)
 {
 	if (salinity < 10050)
-		return waterTypes[FRESHWATER];
+		return gettextFromC::tr(waterTypes[FRESHWATER]);
 	else if (salinity < 10190)
-		return waterTypes[BRACKISHWATER];
+		return gettextFromC::tr(waterTypes[BRACKISHWATER]);
 	else if (salinity < 10210)
-		return waterTypes[EN13319WATER];
+		return gettextFromC::tr(waterTypes[EN13319WATER]);
 	else
-		return waterTypes[SALTWATER];
+		return gettextFromC::tr(waterTypes[SALTWATER]);
+}
+
+QStringList getWaterTypesAsString()
+{
+	QStringList res;
+	res.reserve(std::end(waterTypes) - std::begin(waterTypes)); // Waiting for C++17's std::size()
+	for (const char *t: waterTypes)
+		res.push_back(gettextFromC::tr(t));
+	return res;
 }
 
 QString getSubsurfaceDataPath(QString folderToFind)
@@ -690,13 +707,10 @@ QString getPrintingTemplatePathBundle()
 	return path;
 }
 
-int gettimezoneoffset(timestamp_t when)
+int gettimezoneoffset()
 {
 	QDateTime dt1, dt2;
-	if (when == 0)
-		dt1 = QDateTime::currentDateTime();
-	else
-		dt1 = timestampToDateTime(when);
+	dt1 = QDateTime::currentDateTime();
 	dt2 = dt1.toUTC();
 	dt1.setTimeSpec(Qt::UTC);
 	return dt2.secsTo(dt1);
@@ -832,10 +846,16 @@ int parsePressureToMbar(const QString &text)
 {
 	int mbar;
 	QString numOnly = text;
-	numOnly.replace(",", ".").remove(QRegExp("[^0-9.]"));
+	// different locales use different symbols as group separator or decimal separator
+	// (I think it's usually '.' and ',' - but maybe there are others?)
+	// let's use Qt's help to get the parsing right
+	QString validNumberCharacters("0-9");
+	validNumberCharacters += loc.decimalPoint();
+	validNumberCharacters += loc.groupSeparator();
+	numOnly.remove(QRegExp(QString("[^%1]").arg(validNumberCharacters)));
 	if (numOnly.isEmpty())
 		return 0;
-	double number = numOnly.toDouble();
+	double number = loc.toDouble(numOnly);
 	if (text.contains(gettextFromC::tr("bar"), Qt::CaseInsensitive)) {
 		mbar = lrint(number * 1000);
 	} else if (text.contains(gettextFromC::tr("psi"), Qt::CaseInsensitive)) {
@@ -952,6 +972,12 @@ QString get_dive_date_string(timestamp_t when)
 	return loc.toString(ts.toUTC(), QString(prefs.date_format) + " " + prefs.time_format);
 }
 
+// Get local seconds since Epoch from ISO formatted UTC date time + offset string
+extern "C" time_t get_dive_datetime_from_isostring(char *when) {
+	QDateTime divetime = QDateTime::fromString(when, Qt::ISODate);
+	return (time_t)(divetime.toSecsSinceEpoch());
+}
+
 QString get_short_dive_date_string(timestamp_t when)
 {
 	QDateTime ts;
@@ -1170,11 +1196,6 @@ QString localFilePath(const QString &originalFilename)
 	return localFilenameOf.value(originalFilename, originalFilename);
 }
 
-// the water types need to match the watertypes enum
-const QStringList waterTypes = {
-	gettextFromC::tr("Fresh"), gettextFromC::tr("Brackish"), gettextFromC::tr("EN13319"), gettextFromC::tr("Salt"), gettextFromC::tr("Use DC")
-};
-
 // TODO: Apparently Qt has no simple way of listing the supported video
 // codecs? Do we have to query them by hand using QMediaPlayer::hasSupport()?
 const QStringList videoExtensionsList = {
