@@ -5,6 +5,7 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 #include "core/pref.h"
+#include "subsurface-time.h"
 
 struct picture;
 
@@ -37,7 +38,7 @@ int getCloudURL(QString &filename);
 bool parseGpsText(const QString &gps_text, double *latitude, double *longitude);
 void init_proxy();
 QString getUUID();
-extern const QStringList waterTypes;
+QStringList getWaterTypesAsString();
 extern const QStringList videoExtensionsList;
 QStringList mediaExtensionFilters();
 QStringList imageExtensionFilters();
@@ -61,7 +62,7 @@ QString get_water_type_string(int salinity);
 QString getSubsurfaceDataPath(QString folderToFind);
 QString getPrintingTemplatePathUser();
 QString getPrintingTemplatePathBundle();
-int gettimezoneoffset(timestamp_t when = 0);
+int gettimezoneoffset();
 QDateTime timestampToDateTime(timestamp_t when);
 timestamp_t dateTimeToTimestamp(const QDateTime &t);
 int parseDurationToSeconds(const QString &text);
@@ -147,6 +148,7 @@ const char *subsurface_user_agent();
 enum deco_mode decoMode();
 int parse_seabear_header(const char *filename, char **params, int pnr);
 char *get_current_date();
+time_t get_dive_datetime_from_isostring(char *when);
 void print_qt_versions();
 void lock_planner();
 void unlock_planner();
