@@ -5,10 +5,6 @@
 
 static const QString group = QStringLiteral("TecDetails");
 
-qPrefTechnicalDetails::qPrefTechnicalDetails(QObject *parent) : QObject(parent)
-{
-}
-
 qPrefTechnicalDetails *qPrefTechnicalDetails::instance()
 {
 	static qPrefTechnicalDetails *self = new qPrefTechnicalDetails;
@@ -24,7 +20,6 @@ void qPrefTechnicalDetails::loadSync(bool doSync)
 	disk_calcndltts(doSync);
 	disk_dcceiling(doSync);
 	disk_display_deco_mode(doSync);
-	disk_display_unused_tanks(doSync);
 	disk_ead(doSync);
 	disk_gfhigh(doSync);
 	disk_gflow(doSync);
@@ -35,7 +30,6 @@ void qPrefTechnicalDetails::loadSync(bool doSync)
 	disk_percentagegraph(doSync);
 	disk_redceiling(doSync);
 	disk_rulergraph(doSync);
-	disk_show_average_depth(doSync);
 	disk_show_ccr_sensors(doSync);
 	disk_show_ccr_setpoint(doSync);
 	disk_show_icd(doSync);
@@ -61,8 +55,6 @@ HANDLE_PREFERENCE_BOOL(TechnicalDetails, "dcceiling", dcceiling);
 
 HANDLE_PREFERENCE_ENUM(TechnicalDetails, deco_mode, "display_deco_mode", display_deco_mode);
 
-HANDLE_PREFERENCE_BOOL(TechnicalDetails, "display_unused_tanks", display_unused_tanks);
-
 HANDLE_PREFERENCE_BOOL(TechnicalDetails, "ead", ead);
 
 void qPrefTechnicalDetails::set_gfhigh(int value)
@@ -119,8 +111,6 @@ HANDLE_PREFERENCE_BOOL(TechnicalDetails, "redceiling", redceiling);
 
 HANDLE_PREFERENCE_BOOL(TechnicalDetails, "RulerBar", rulergraph);
 
-HANDLE_PREFERENCE_BOOL(TechnicalDetails, "show_average_depth", show_average_depth);
-
 HANDLE_PREFERENCE_BOOL(TechnicalDetails, "show_ccr_sensors", show_ccr_sensors);
 
 HANDLE_PREFERENCE_BOOL(TechnicalDetails, "show_ccr_setpoint", show_ccr_setpoint);
