@@ -29,6 +29,7 @@
 #include "errorhelper.h"
 #include "file.h"
 #include "tag.h"
+#include "subsurface-time.h"
 #include "core/subsurface-string.h"
 
 #define ERR_FS_ALMOST_FULL QT_TRANSLATE_NOOP("gettextFromC", "Uemis Zurich: the file system is almost full.\nDisconnect/reconnect the dive computer\nand click \'Retry\'")
@@ -105,10 +106,10 @@ static void add_to_divespot_mapping(int divespot_id, struct dive_site *ds)
 	struct divespot_mapping *ndm = (struct divespot_mapping*)calloc(1, sizeof(struct divespot_mapping));
 	struct divespot_mapping **pdm = &divespot_mapping;
 	struct divespot_mapping *cdm = *pdm;
-	
+
 	while (cdm && cdm->next)
 		cdm = cdm->next;
-	
+
 	ndm->divespot_id = divespot_id;
 	ndm->dive_site = ds;
 	ndm->next = NULL;
@@ -232,13 +233,13 @@ static void uemis_info(const char *fmt, ...)
 
 static long bytes_available(int file)
 {
-	long result;
+	long result, r2;
 	long now = lseek(file, 0, SEEK_CUR);
 	if (now == -1)
 		return 0;
 	result = lseek(file, 0, SEEK_END);
-	lseek(file, now, SEEK_SET);
-	if (now == -1 || result == -1)
+	r2 = lseek(file, now, SEEK_SET);
+	if (now == -1 || result == -1 || r2 == -1)
 		return 0;
 	return result;
 }
@@ -603,8 +604,9 @@ static bool uemis_get_answer(const char *path, char *request, int n_param_in,
 			free(ans_path);
 			return false;
 		}
-		if (read(ans_file, tmp, 100) < 0) {
+		if (read(ans_file, tmp, 100) < 3) {
 			free(ans_path);
+			close(ans_file);
 			return false;
 		}
 		close(ans_file);
@@ -1183,7 +1185,7 @@ static bool load_uemis_divespot(const char *mountpath, int divespot_id)
 static void get_uemis_divespot(device_data_t *devdata, const char *mountpath, int divespot_id, struct dive *dive)
 {
 	struct dive_site *nds = dive->dive_site;
-	
+
 	if (is_divespot_mappable(divespot_id)) {
 		struct dive_site *ds = get_dive_site_by_divespot_id(divespot_id);
 		unregister_dive_from_dive_site(dive);
