@@ -106,6 +106,7 @@ QWidget *ComboBoxDelegate::createEditor(QWidget *parent, const QStyleOptionViewI
 	comboDelegate->setEditable(true);
 	comboDelegate->completer()->setCaseSensitivity(Qt::CaseInsensitive);
 	comboDelegate->completer()->setCompletionMode(QCompleter::PopupCompletion);
+	comboDelegate->completer()->setFilterMode(Qt::MatchContains);
 	comboDelegate->view()->setEditTriggers(QAbstractItemView::AllEditTriggers);
 	comboDelegate->lineEdit()->installEventFilter(const_cast<QObject *>(qobject_cast<const QObject *>(this)));
 	comboDelegate->lineEdit()->setEnabled(editable);
@@ -404,12 +405,12 @@ void LocationFilterDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 	for (int i = 0; i < 3; i++) {
 		if (prefs.geocoding.category[i] == TC_NONE)
 			continue;
-		int idx = taxonomy_index_for_category(&ds->taxonomy, prefs.geocoding.category[i]);
-		if (idx == -1)
+		const char *value = taxonomy_get_value(&ds->taxonomy, prefs.geocoding.category[i]);
+		if (empty_string(value))
 			continue;
 		if(!bottomText.isEmpty())
 			bottomText += " / ";
-		bottomText += QString(ds->taxonomy.category[idx].value);
+		bottomText += QString(value);
 	}
 
 	if (bottomText.isEmpty())
