@@ -18,6 +18,7 @@ public:
 	void clear() override;
 private slots:
 	void divesChanged(const QVector<dive *> &dives, DiveField field);
+	void cylinderChanged(dive *d);
 	void diveModeChanged(int index);
 	void on_atmPressVal_editingFinished();
 	void on_atmPressType_currentIndexChanged(int index);
@@ -43,7 +44,6 @@ private:
 	void divesEdited(int);
 	void closeWarning();
 	void showCurrentWidget(bool show, int position);
-	QStringList waterTypes;
 };
 
 #endif
