@@ -8,6 +8,7 @@
 #include "desktop-widgets/tab-widgets/maintab.h"
 #include "desktop-widgets/mainwindow.h"
 #include "desktop-widgets/mapwidget.h"
+#include "desktop-widgets/preferences/preferencesdialog.h"
 #include "core/qthelper.h"
 #include "core/trip.h"
 #include "qt-models/diveplannermodel.h"
@@ -58,23 +59,20 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 {
 	ui.setupUi(this);
 
-	extraWidgets << new TabDiveEquipment();
+	extraWidgets << new TabDiveEquipment(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Equipment"));
-	extraWidgets << new TabDiveInformation();
+	extraWidgets << new TabDiveInformation(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Information"));
-	extraWidgets << new TabDiveStatistics();
+	extraWidgets << new TabDiveStatistics(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Statistics"));
-	extraWidgets << new TabDivePhotos();
+	extraWidgets << new TabDivePhotos(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Media"));
-	extraWidgets << new TabDiveExtraInfo();
+	extraWidgets << new TabDiveExtraInfo(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Extra Info"));
-	extraWidgets << new TabDiveSite();
+	extraWidgets << new TabDiveSite(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Dive sites"));
 
-	ui.dateEdit->setDisplayFormat(prefs.date_format);
-	ui.timeEdit->setDisplayFormat(prefs.time_format);
-
-	memset(&displayed_dive, 0, sizeof(displayed_dive));
+	updateDateTimeFields();
 
 	closeMessage();
 
@@ -88,6 +86,11 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	connect(ui.location, &DiveLocationLineEdit::currentChanged, MapWidget::instance(), &MapWidget::centerOnIndex);
 	connect(ui.location, &DiveLocationLineEdit::editingFinished, this, &MainTab::on_location_diveSiteSelected);
 
+	// One might think that we could listen to the precise property-changed signals of the preferences system.
+	// Alas, this is not the case. When the user switches to system-format, the preferences sends the according
+	// signal. However, the correct date and time format is set by the preferences dialog later. This should be fixed.
+	connect(PreferencesDialog::instance(), &PreferencesDialog::settingsChanged, this, &MainTab::updateDateTimeFields);
+
 	QAction *action = new QAction(tr("Apply changes"), this);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(acceptChanges()));
 	ui.diveNotesMessage->addAction(action);
@@ -180,8 +183,10 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	ui.diveTripLocation->hide();
 }
 
-MainTab::~MainTab()
+void MainTab::updateDateTimeFields()
 {
+	ui.dateEdit->setDisplayFormat(prefs.date_format);
+	ui.timeEdit->setDisplayFormat(prefs.time_format);
 }
 
 void MainTab::hideMessage()
@@ -302,14 +307,6 @@ void MainTab::updateNotes(const struct dive *d)
 	}
 }
 
-static QDateTime timestampToDateTime(timestamp_t when)
-{
-	// Subsurface always uses "local time" as in "whatever was the local time at the location"
-	// so all time stamps have no time zone information and are in UTC
-	QDateTime localTime = QDateTime::fromMSecsSinceEpoch(1000 * when, Qt::UTC);
-	localTime.setTimeSpec(Qt::UTC);
-	return localTime;
-}
 void MainTab::updateDateTime(const struct dive *d)
 {
 	QDateTime localTime = timestampToDateTime(d->when);
@@ -337,6 +334,11 @@ void MainTab::updateDiveSite(struct dive *d)
 		ui.locationTags->clear();
 		ui.editDiveSiteButton->setEnabled(false);
 	}
+
+	if (ui.locationTags->text().isEmpty())
+		ui.locationTags->hide();
+	else
+		ui.locationTags->show();
 }
 
 void MainTab::updateDiveInfo()
@@ -355,17 +357,18 @@ void MainTab::updateDiveInfo()
 
 	ignoreInput = true; // don't trigger on changes to the widgets
 
-	for (TabBase *widget: extraWidgets)
-		widget->updateData();
-
 	if (current_dive) {
+		for (TabBase *widget: extraWidgets)
+			widget->updateData();
+
 		// If we're on the dive-site tab, we don't want to switch tab when entering / exiting
 		// trip mode. The reason is that
 		// 1) this disrupts the user-experience and
 		// 2) the filter is reset, potentially erasing the current trip under our feet.
 		// TODO: Don't hard code tab location!
 		bool onDiveSiteTab = ui.tabWidget->currentIndex() == 6;
-		if ((currentTrip = MainWindow::instance()->diveList->singleSelectedTrip()) != nullptr) {
+		currentTrip = single_selected_trip();
+		if (currentTrip) {
 			// Remember the tab selected for last dive but only if we're not on the dive site tab
 			if (lastSelectedDive && !onDiveSiteTab)
 				lastTabSelectedDive = ui.tabWidget->currentIndex();
@@ -412,7 +415,6 @@ void MainTab::updateDiveInfo()
 			if (!lastSelectedDive && !onDiveSiteTab)
 				ui.tabWidget->setCurrentIndex(lastTabSelectedDive);
 			lastSelectedDive = true;
-			currentTrip = NULL;
 			// make all the fields visible writeable
 			ui.diveTripLocation->hide();
 			ui.location->show();
@@ -450,10 +452,6 @@ void MainTab::updateDiveInfo()
 		ui.duration->setText(render_seconds_to_string(current_dive->duration.seconds));
 		ui.depth->setText(get_depth_string(current_dive->maxdepth, true));
 
-		if(ui.locationTags->text().isEmpty())
-			ui.locationTags->hide();
-		else
-			ui.locationTags->show();
 		ui.editDiveSiteButton->setEnabled(!ui.location->text().isEmpty());
 		/* unset the special value text for date and time, just in case someone dove at midnight */
 		ui.dateEdit->setSpecialValueText(QString());
@@ -511,7 +509,7 @@ void MainTab::acceptChanges()
 	if (editMode) {
 		MainWindow::instance()->diveList->reload();
 		MainWindow::instance()->refreshDisplay();
-		MainWindow::instance()->graphics->replot();
+		MainWindow::instance()->graphics->plotDive(current_dive, true);
 	} else {
 		MainWindow::instance()->refreshDisplay();
 	}
@@ -547,7 +545,7 @@ void MainTab::rejectChanges()
 	updateDiveInfo();
 
 	// show the profile and dive info
-	MainWindow::instance()->graphics->replot();
+	MainWindow::instance()->graphics->plotDive(current_dive, true);
 	MainWindow::instance()->setEnabledToolbar(true);
 	ui.editDiveSiteButton->setEnabled(!ui.location->text().isEmpty());
 }
@@ -600,30 +598,28 @@ void MainTab::on_depth_editingFinished()
 // all dives are shifted by an offset.
 static void shiftTime(QDateTime &dateTime)
 {
-	timestamp_t when = dateTime.toTime_t();
+	timestamp_t when = dateTimeToTimestamp(dateTime);
 	if (current_dive && current_dive->when != when) {
 		timestamp_t offset = when - current_dive->when;
 		Command::shiftTime(getDiveSelection(), (int)offset);
 	}
 }
 
-void MainTab::on_dateEdit_dateChanged(const QDate &date)
+void MainTab::on_dateEdit_editingFinished()
 {
 	if (ignoreInput || !current_dive)
 		return;
-	QDateTime dateTime = QDateTime::fromMSecsSinceEpoch(1000*current_dive->when, Qt::UTC);
-	dateTime.setTimeSpec(Qt::UTC);
-	dateTime.setDate(date);
+	QDateTime dateTime = timestampToDateTime(current_dive->when);
+	dateTime.setDate(ui.dateEdit->date());
 	shiftTime(dateTime);
 }
 
-void MainTab::on_timeEdit_timeChanged(const QTime &time)
+void MainTab::on_timeEdit_editingFinished()
 {
 	if (ignoreInput || !current_dive)
 		return;
-	QDateTime dateTime = QDateTime::fromMSecsSinceEpoch(1000*current_dive->when, Qt::UTC);
-	dateTime.setTimeSpec(Qt::UTC);
-	dateTime.setTime(time);
+	QDateTime dateTime = timestampToDateTime(current_dive->when);
+	dateTime.setTime(ui.timeEdit->time());
 	shiftTime(dateTime);
 }
 
