@@ -60,6 +60,7 @@ class QMLManager : public QObject {
 	Q_PROPERTY(QString redoText READ getRedoText NOTIFY redoTextChanged) // this is a read-only property
 	Q_PROPERTY(bool diveListProcessing MEMBER m_diveListProcessing  WRITE setDiveListProcessing NOTIFY diveListProcessingChanged)
 	Q_PROPERTY(bool initialized MEMBER m_initialized NOTIFY initializedChanged)
+	Q_PROPERTY(QString syncState READ getSyncState NOTIFY syncStateChanged)
 
 public:
 	QMLManager();
@@ -175,6 +176,8 @@ public:
 	void setOldStatus(const qPrefCloudStorage::cloud_status value);
 	void rememberOldStatus();
 
+	QString getSyncState() const;
+
 public slots:
 	void appInitialized();
 	void applicationStateChanged(Qt::ApplicationState state);
@@ -263,9 +266,11 @@ private:
 	bool checkDuration(const DiveObjectHelper &myDive, struct dive *d, QString duration);
 	bool checkDepth(const DiveObjectHelper &myDive, struct dive *d, QString depth);
 	bool currentGitLocalOnly;
+	bool localChanges;
 	QString m_progressMessage;
 	bool m_btEnabled;
 	void updateAllGlobalLists();
+	void updateHaveLocalChanges(bool status);
 
 	location_t getGps(QString &gps);
 	QString m_pluggedInDeviceName;
@@ -315,6 +320,7 @@ signals:
 	void undoTextChanged();
 	void redoTextChanged();
 	void restartDownloadSignal();
+	void syncStateChanged();
 
 	// From upload process
 	void uploadFinish(bool success, const QString &text);
