@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "profile-widget/profilewidget2.h"
 #include "qt-models/diveplotdatamodel.h"
-#include "core/divecomputer.h"
 #include "core/subsurface-string.h"
 #include "core/qthelper.h"
 #include "core/picture.h"
@@ -796,6 +795,9 @@ void ProfileWidget2::plotDive(const struct dive *d, bool force, bool doClearPict
 		item->setModel(dataModel);
 		item->setEvent(event, lastgasmix);
 		item->setZValue(2);
+#ifndef SUBSURFACE_MOBILE
+		item->setScale(printMode ? 4 :1);
+#endif
 		scene()->addItem(item);
 		eventItems.push_back(item);
 		if (event_is_gaschange(event))
@@ -1399,6 +1401,18 @@ struct int ProfileWidget2::getEntryFromPos(QPointF pos)
 #endif
 
 #ifndef SUBSURFACE_MOBILE
+/// Prints cylinder information for display.
+/// eg : "Cyl 1 (AL80 EAN32)"
+static QString printCylinderDescription(int i, const cylinder_t *cylinder)
+{
+	QString label = gettextFromC::tr("Cyl") + QString(" %1").arg(i+1);
+	if( cylinder != NULL ) {
+		QString mix = get_gas_string(cylinder->gasmix);
+		label += QString(" (%2 %3)").arg(cylinder->type.description).arg(mix);
+	}
+	return label;
+}
+
 void ProfileWidget2::contextMenuEvent(QContextMenuEvent *event)
 {
 	if (currentState == ADD || currentState == PLAN) {
@@ -1421,13 +1435,13 @@ void ProfileWidget2::contextMenuEvent(QContextMenuEvent *event)
 			parentItem = parentItem->parentItem();
 		}
 		if (isDCName) {
-			if (dc_number == 0 && count_divecomputers(current_dive) == 1)
+			if (dc_number == 0 && number_of_computers(current_dive) == 1)
 				// nothing to do, can't delete or reorder
 				return;
 			// create menu to show when right clicking on dive computer name
 			if (dc_number > 0)
 				m.addAction(tr("Make first dive computer"), this, &ProfileWidget2::makeFirstDC);
-			if (count_divecomputers(current_dive) > 1) {
+			if (number_of_computers(current_dive) > 1) {
 				m.addAction(tr("Delete this dive computer"), this, &ProfileWidget2::deleteCurrentDC);
 				m.addAction(tr("Split this dive computer into own dive"), this, &ProfileWidget2::splitCurrentDC);
 			}
@@ -1440,12 +1454,25 @@ void ProfileWidget2::contextMenuEvent(QContextMenuEvent *event)
 	QPointF scenePos = mapToScene(mapFromGlobal(event->globalPos()));
 	qreal sec_val = timeAxis->valueAt(scenePos);
 	int seconds = (sec_val < 0.0) ? 0 : (int)sec_val;
-	if (current_dive && current_dive->cylinders.nr > 1) {
+	DiveEventItem *item = dynamic_cast<DiveEventItem *>(sceneItem);
+
+	// Add or edit Gas Change
+	if (current_dive && item && event_is_gaschange(item->getEvent())) {
+		int eventTime = item->getEvent()->time.seconds;
+		QMenu *gasChange = m.addMenu(tr("Edit Gas Change"));
+		for (int i = 0; i < current_dive->cylinders.nr; i++) {
+			const cylinder_t *cylinder = get_cylinder(current_dive, i);
+			QString label = printCylinderDescription(i, cylinder);
+			gasChange->addAction(label, [this, i, eventTime] { changeGas(i, eventTime); });
+		}
+	} else if (current_dive && current_dive->cylinders.nr > 1) {
 		// if we have more than one gas, offer to switch to another one
 		QMenu *gasChange = m.addMenu(tr("Add gas change"));
-		for (int i = 0; i < current_dive->cylinders.nr; i++)
-			gasChange->addAction(QString(current_dive->cylinders.cylinders[i].type.description) + tr(" (cyl. %1)").arg(i + 1),
-					     [this, i, seconds] { changeGas(i, seconds); });
+		for (int i = 0; i < current_dive->cylinders.nr; i++) {
+			const cylinder_t *cylinder = get_cylinder(current_dive, i);
+			QString label = printCylinderDescription(i, cylinder);
+			gasChange->addAction(label, [this, i, seconds] { changeGas(i, seconds); });
+		}
 	}
 	m.addAction(tr("Add setpoint change"), [this, seconds]() { ProfileWidget2::addSetpointChange(seconds); });
 	m.addAction(tr("Add bookmark"), [this, seconds]() { addBookmark(seconds); });
