@@ -3,7 +3,7 @@
 #define DIVECOMPUTERMODEL_H
 
 #include "qt-models/cleanertablemodel.h"
-#include "core/divecomputer.h"
+#include "core/device.h"
 
 class DiveComputerModel : public CleanerTableModel {
 	Q_OBJECT
@@ -26,7 +26,6 @@ slots:
 	void remove(const QModelIndex &index);
 
 private:
-	int numRows;
 	QVector<DiveComputerNode> dcs;
 };
 
