@@ -1,6 +1,5 @@
 // SPDX-License-Identifier: GPL-2.0
 #include <QQmlEngine>
-#include <QDebug>
 #include <QQuickItem>
 
 #include "map-widget/qmlmapwidgethelper.h"
@@ -10,13 +9,16 @@
 #include "core/ssrf.h"
 
 #ifdef SUBSURFACE_MOBILE
+#include <QApplication>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include "mobile-widgets/themeinterface.h"
 #include "mobile-widgets/qmlmanager.h"
-#include "mobile-widgets/qmlprefs.h"
-#include "qt-models/divelistmodel.h"
+#include "mobile-widgets/qmlinterface.h"
+#include "qt-models/divesummarymodel.h"
 #include "qt-models/gpslistmodel.h"
 #include "qt-models/messagehandlermodel.h"
+#include "qt-models/mobilelistmodel.h"
 #include "profile-widget/qmlprofile.h"
 #include "core/downloadfromdcthread.h"
 #include "qt-models/diveimportedmodel.h"
@@ -25,7 +27,12 @@
 #include "desktop-widgets/mainwindow.h"
 #endif
 
-#ifndef SUBSURFACE_TEST_DATA
+#if defined(Q_OS_ANDROID)
+QString getAndroidHWInfo(); // from android.cpp
+#include <QApplication>
+#include <QFontDatabase>
+#endif /* Q_OS_ANDROID */
+
 QObject *qqWindowObject = NULL;
 
 // Forward declaration
@@ -49,17 +56,33 @@ void exit_ui()
 #ifndef SUBSURFACE_MOBILE
 	delete MainWindow::instance();
 #endif // SUBSURFACE_MOBILE
-	delete qApp;
 	free((void *)existing_filename);
 }
 
 void run_ui()
 {
-
 #ifdef SUBSURFACE_MOBILE
+#if defined(Q_OS_ANDROID)
+	if (getAndroidHWInfo().contains("/OnePlus/")) {
+		QFontDatabase db;
+		int id = QFontDatabase::addApplicationFont(":/fonts/Roboto-Regular.ttf");
+		QString family = QFontDatabase::applicationFontFamilies(id).at(0);
+		QFont newDefaultFont;
+		newDefaultFont.setFamily(family);
+		(static_cast<QApplication *>(QCoreApplication::instance()))->setFont(newDefaultFont);
+		qDebug() << "Detected OnePlus device, trying to force bundled font" << family;
+		QFont defaultFont = (static_cast<QApplication *>(QCoreApplication::instance()))->font();
+		qDebug() << "Qt reports default font is set as" << defaultFont.family();
+	}
+#endif
+	QScreen *appScreen = QApplication::screens().at(0);
+	int availableScreenWidth = appScreen->availableSize().width();
 	QQmlApplicationEngine engine;
+	QQmlContext *ctxt = engine.rootContext();
+
+	// Register qml interface classes
+	QMLInterface::setup(ctxt);
 	register_qml_types(&engine);
-	LOG_STP("run_ui qml engine started");
 	KirigamiPlugin::getInstance().registerTypes();
 #if defined(__APPLE__) && !defined(Q_OS_IOS)
 	// when running the QML UI on a Mac the deployment of the QML Components seems
@@ -75,32 +98,35 @@ void run_ui()
 	qDebug() << "QML import path" << engine.importPathList();
 #endif // __APPLE__ not Q_OS_IOS
 	engine.addImportPath("qrc://imports");
-	DiveListModel diveListModel;
-	LOG_STP("run_ui diveListModel started");
-	DiveListSortModel *sortModel = new DiveListSortModel(0);
-	sortModel->setSourceModel(&diveListModel);
-	sortModel->setDynamicSortFilter(true);
-	sortModel->setSortRole(DiveListModel::DiveDateRole);
-	sortModel->sort(0, Qt::DescendingOrder);
-	LOG_STP("run_ui diveListModel sorted");
-	GpsListModel gpsListModel;
-	QSortFilterProxyModel *gpsSortModel = new QSortFilterProxyModel(0);
-	gpsSortModel->setSourceModel(&gpsListModel);
+	QSortFilterProxyModel *gpsSortModel = new QSortFilterProxyModel(nullptr);
+	gpsSortModel->setSourceModel(GpsListModel::instance());
 	gpsSortModel->setDynamicSortFilter(true);
 	gpsSortModel->setSortRole(GpsListModel::GpsWhenRole);
 	gpsSortModel->sort(0, Qt::DescendingOrder);
-	QQmlContext *ctxt = engine.rootContext();
-	ctxt->setContextProperty("diveModel", sortModel);
 	ctxt->setContextProperty("gpsModel", gpsSortModel);
 	ctxt->setContextProperty("vendorList", vendorList);
+	ctxt->setContextProperty("swipeModel", MobileModels::instance()->swipeModel());
+	ctxt->setContextProperty("diveModel", MobileModels::instance()->listModel());
 	set_non_bt_addresses();
-	LOG_STP("run_ui set_non_bt_adresses");
 
 	ctxt->setContextProperty("connectionListModel", &connectionListModel);
 	ctxt->setContextProperty("logModel", MessageHandlerModel::self());
+	ctxt->setContextProperty("subsurfaceTheme", ThemeInterface::instance());
 
+	qmlRegisterUncreatableType<QMLManager>("org.subsurfacedivelog.mobile",1,0,"ExportType","Enum is not a type");
+
+#ifdef SUBSURFACE_MOBILE_DESKTOP
+	if (testqml) {
+		QString fileLoad(testqml);
+		fileLoad += "/main.qml";
+		engine.load(QUrl(fileLoad));
+	} else {
+		engine.load(QUrl(QStringLiteral("qrc:///qml/main.qml")));
+	}
+#else
 	engine.load(QUrl(QStringLiteral("qrc:///qml/main.qml")));
-	LOG_STP("run_ui qml loaded");
+#endif
+	qDebug() << "loaded main.qml";
 	qqWindowObject = engine.rootObjects().value(0);
 	if (!qqWindowObject) {
 		fprintf(stderr, "can't create window object\n");
@@ -110,24 +136,39 @@ void run_ui()
 	qml_window->setIcon(QIcon(":subsurface-mobile-icon"));
 	qDebug() << "qqwindow devicePixelRatio" << qml_window->devicePixelRatio() << qml_window->screen()->devicePixelRatio();
 	QScreen *screen = qml_window->screen();
+	int qmlWW = qml_window->width();
+	int qmlSW = screen->size().width();
+	qDebug() << "qml_window reports width as" << qmlWW << "associated screen width" << qmlSW << "Qt screen reports width as" << availableScreenWidth;
 	QObject::connect(qml_window, &QQuickWindow::screenChanged, QMLManager::instance(), &QMLManager::screenChanged);
 	QMLManager *manager = QMLManager::instance();
-	LOG_STP("run_ui qmlmanager instance started");
-	// now that the log file is initialized...
-	show_computer_list();
-	LOG_STP("run_ui show_computer_list");
 
 	manager->setDevicePixelRatio(qml_window->devicePixelRatio(), qml_window->screen());
-	manager->dlSortModel = sortModel;
 	manager->qmlWindow = qqWindowObject;
 	manager->screenChanged(screen);
 	qDebug() << "qqwindow screen has ldpi/pdpi" << screen->logicalDotsPerInch() << screen->physicalDotsPerInch();
 #if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
-	qml_window->setHeight(1200);
-	qml_window->setWidth(800);
+	int width = 800;
+	int height = 1200;
+	if (qEnvironmentVariableIsSet("SUBSURFACE_MOBILE_WIDTH")) {
+		bool ok;
+		int width_override = qEnvironmentVariableIntValue("SUBSURFACE_MOBILE_WIDTH", &ok);
+		if (ok) {
+			width = width_override;
+			qDebug() << "overriding window width:" << width;
+		}
+	}
+	if (qEnvironmentVariableIsSet("SUBSURFACE_MOBILE_HEIGHT")) {
+		bool ok;
+		int height_override = qEnvironmentVariableIntValue("SUBSURFACE_MOBILE_HEIGHT", &ok);
+		if (ok) {
+			height = height_override;
+			qDebug() << "overriding window height:" << height;
+		}
+	}
+	qml_window->setHeight(height);
+	qml_window->setWidth(width);
 #endif // not Q_OS_ANDROID and not Q_OS_IOS
 	qml_window->show();
-	LOG_STP("run_ui running exec");
 #else
 	MainWindow::instance()->show();
 #endif // SUBSURFACE_MOBILE
@@ -139,30 +180,26 @@ static void register_meta_types()
 {
 	qRegisterMetaType<duration_t>();
 }
-#endif // not SUBSURFACE_TEST_DATA
 
-#define REGISTER_TYPE(useClass, useQML) \
-	rc = qmlRegisterType<useClass>("org.subsurfacedivelog.mobile", 1, 0, useQML); \
-	if (rc < 0) \
-		qWarning() << "ERROR: Cannot register " << useQML << ", QML will not work!!";
+template <typename T>
+static void register_qml_type(const char *name)
+{
+	if(qmlRegisterType<T>("org.subsurfacedivelog.mobile", 1, 0, name) < 0)
+		qWarning("ERROR: Cannot register %s, QML will not work!!", name);
+}
 
-void register_qml_types(QQmlEngine *engine)
+static void register_qml_types(QQmlEngine *engine)
 {
 	// register qPref*
 	qPref::registerQML(engine);
 
-#ifndef SUBSURFACE_TEST_DATA
-	int rc;
-
 #ifdef SUBSURFACE_MOBILE
-	REGISTER_TYPE(QMLManager, "QMLManager");
-	REGISTER_TYPE(QMLPrefs, "QMLPrefs");
-	REGISTER_TYPE(QMLProfile, "QMLProfile");
-	REGISTER_TYPE(DownloadThread, "DCDownloadThread");
-	REGISTER_TYPE(DiveImportedModel, "DCImportModel");
+	register_qml_type<QMLManager>("QMLManager");
+	register_qml_type<QMLProfile>("QMLProfile");
+	register_qml_type<DiveImportedModel>("DCImportModel");
+	register_qml_type<DiveSummaryModel>("DiveSummaryModel");
 #endif // not SUBSURFACE_MOBILE
 
-	REGISTER_TYPE(MapWidgetHelper, "MapWidgetHelper");
-	REGISTER_TYPE(MapLocationModel, "MapLocationModel");
-#endif // not SUBSURFACE_TEST_DATA
+	register_qml_type<MapWidgetHelper>("MapWidgetHelper");
+	register_qml_type<MapLocationModel>("MapLocationModel");
 }
