@@ -6,6 +6,7 @@
 #include <string.h>
 #include <time.h>
 
+#include "core/dive.h"
 #include "core/color.h"
 #include "core/downloadfromdcthread.h"
 #include "core/qt-gui.h"
@@ -14,6 +15,7 @@
 #include "core/settings/qPref.h"
 #include "core/settings/qPrefDisplay.h"
 #include "core/tag.h"
+#include "core/settings/qPrefCloudStorage.h"
 
 #include <QApplication>
 #include <QLocale>
@@ -23,48 +25,15 @@
 
 // Implementation of STP logging
 #include "core/ssrf.h"
-#ifdef ENABLE_STARTUP_TIMING
-#include <QElapsedTimer>
-#include <QMutex>
-#include <QMutexLocker>
-void log_stp(const char *ident, QString *buf)
-{
-	static bool firstCall = true;
-	static QElapsedTimer stpDuration;
-	static QString stpText;
-	static QMutex logMutex;
-
-	QMutexLocker l(&logMutex);
-
-	if (firstCall) {
-		firstCall = false;
-		stpDuration.start();
-	}
-	if (ident)
-		stpText += QString("STP ")
-				   .append(QString::number(stpDuration.elapsed()))
-				   .append(" ms, ")
-				   .append(ident)
-				   .append("\n");
-	if (buf) {
-		*buf += "---------- startup timer ----------\n";
-		*buf += stpText;
-	}
-}
-#endif // ENABLE_STARTUP_TIMING
-
 
 int main(int argc, char **argv)
 {
-	LOG_STP("main starting");
-
 	int i;
 	QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 	QLoggingCategory::setFilterRules(QStringLiteral("qt.bluetooth* = true"));
 
 	// Start application
-	new QApplication(argc, argv);
-	LOG_STP("main Qt started");
+	std::unique_ptr<QApplication> app(new QApplication(argc, argv));
 
 	// and get comand line arguments
 	QStringList arguments = QCoreApplication::arguments();
@@ -79,7 +48,6 @@ int main(int argc, char **argv)
 		}
 	}
 	git_libgit2_init();
-	LOG_STP("main git loaded");
 	setup_system_prefs();
 	if (QLocale().measurementSystem() == QLocale::MetricSystem)
 		default_prefs.units = SI_units;
@@ -89,11 +57,8 @@ int main(int argc, char **argv)
 	fill_computer_list();
 
 	parse_xml_init();
-	LOG_STP("main xml parsed");
 	taglist_init_global();
-	LOG_STP("main taglist done");
 	init_ui();
-	LOG_STP("main init_ui done");
 	if (prefs.default_file_behavior == LOCAL_DEFAULT_FILE)
 		set_filename(prefs.default_filename);
 	else
@@ -101,13 +66,13 @@ int main(int argc, char **argv)
 
 	// some hard coded settings
 	qPrefDisplay::set_animation_speed(0); // we render the profile to pixmap, no animations
+	qPrefCloudStorage::set_save_password_local(true);
 
 	// always show the divecomputer reported ceiling in red
 	prefs.redceiling = 1;
 
 	init_proxy();
 
-	LOG_STP("main call run_ui (continue in qmlmanager)");
 	if (!quit)
 		run_ui();
 	exit_ui();
@@ -124,9 +89,7 @@ int main(int argc, char **argv)
 
 void set_non_bt_addresses()
 {
-#if defined(Q_OS_ANDROID)
-	connectionListModel.addAddress("FTDI");
-#elif defined(Q_OS_LINUX) // since this is in the else, it does NOT include Android
+#if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
 	connectionListModel.addAddress("/dev/ttyS0");
 	connectionListModel.addAddress("/dev/ttyS1");
 	connectionListModel.addAddress("/dev/ttyS2");
@@ -134,6 +97,9 @@ void set_non_bt_addresses()
 	// this makes debugging so much easier - use the simulator
 	connectionListModel.addAddress("/tmp/ttyS1");
 #endif
+#if defined(SERIAL_FTDI)
+	connectionListModel.addAddress("FTDI");
+#endif
 }
 
 bool haveFilesOnCommandLine()
