@@ -22,7 +22,7 @@ void TestPicture::initTestCase()
 
 void TestPicture::addPicture()
 {
-	struct dive *dive;
+	struct dive *dive, *dive1, *dive2;
 	struct picture *pic1, *pic2;
 	verbose = 1;
 
@@ -31,17 +31,25 @@ void TestPicture::addPicture()
 	// Pictures will be added to selected dives
 	dive->selected = true;
 	QVERIFY(dive != NULL);
-	pic1 = dive->picture_list;
 	// So far no picture in dive
-	QVERIFY(pic1 == NULL);
+	QVERIFY(dive->pictures.nr == 0);
 
-	create_picture(SUBSURFACE_TEST_DATA "/dives/images/wreck.jpg", 0, false);
-	create_picture(SUBSURFACE_TEST_DATA "/dives/images/data_after_EOI.jpg", 0, false);
-	pic1 = dive->picture_list;
-	pic2 = pic1->next;
-	// Now there are two picture2
+	pic1 = create_picture(SUBSURFACE_TEST_DATA "/dives/images/wreck.jpg", 0, false, &dive1);
+	pic2 = create_picture(SUBSURFACE_TEST_DATA "/dives/images/data_after_EOI.jpg", 0, false, &dive2);
 	QVERIFY(pic1 != NULL);
 	QVERIFY(pic2 != NULL);
+	QVERIFY(dive1 == dive);
+	QVERIFY(dive2 == dive);
+
+	add_picture(&dive->pictures, *pic1);
+	add_picture(&dive->pictures, *pic2);
+	free(pic1);
+	free(pic2);
+
+	// Now there are two pictures
+	QVERIFY(dive->pictures.nr == 2);
+	pic1 = &dive->pictures.pictures[0];
+	pic2 = &dive->pictures.pictures[1];
 	// 1st appearing at time 21:01
 	// 2nd appearing at time 22:01
 	QVERIFY(pic1->offset.seconds == 1261);
@@ -55,5 +63,4 @@ void TestPicture::addPicture()
 	QCOMPARE(localFilePath(pic2->filename), QString(PIC2_NAME));
 }
 
-
 QTEST_GUILESS_MAIN(TestPicture)
